@@ -29,23 +29,23 @@ class UR10(ERobot):
 
     def __init__(self):
 
-        args = super().urdf_to_ets_args(
+        links, name, urdf_string, urdf_filepath = self.URDF_read(
             "ur_description/urdf/ur10_joint_limited_robot.urdf.xacro"
         )
 
         super().__init__(
-                args[0],
-                name=args[1],
-                manufacturer='Universal Robotics'
-            )
+            links,
+            name=name.upper(),
+            manufacturer="Universal Robotics",
+            urdf_string=urdf_string,
+            urdf_filepath=urdf_filepath,
+        )
 
-        self.addconfiguration(
-            "qz", np.array([0, 0, 0, 0, 0, 0]))
-        self.addconfiguration(
-            "qr", np.array([np.pi, 0, 0, 0, np.pi/2, 0]))
+        self.addconfiguration("qz", np.array([0, 0, 0, 0, 0, 0]))
+        self.addconfiguration("qr", np.array([np.pi, 0, 0, 0, np.pi / 2, 0]))
 
 
-if __name__ == '__main__':   # pragma nocover
+if __name__ == "__main__":  # pragma nocover
 
     robot = UR10()
     print(robot)
