@@ -29,24 +29,26 @@ class vx300(ERobot):
     .. codeauthor:: Jesse Haviland
     .. sectionauthor:: Peter Corke
     """
+
     def __init__(self):
 
-        args = super().urdf_to_ets_args(
-            "interbotix_descriptions/urdf/vx300.urdf.xacro")
+        links, name, urdf_string, urdf_filepath = self.URDF_read(
+            "interbotix_descriptions/urdf/vx300.urdf.xacro"
+        )
 
         super().__init__(
-                args[0],
-                name=args[1],
-                manufacturer='Interbotix'
-            )
+            links,
+            name=name,
+            manufacturer="Interbotix",
+            urdf_string=urdf_string,
+            urdf_filepath=urdf_filepath,
+        )
 
-        self.addconfiguration(
-            "qz", np.array([0, 0, 0, 0, 0, 0, 0, 0]))
-        self.addconfiguration(
-            "qr", np.array([0, -0.3, 0, -2.2, 0, 2.0, np.pi/4, 0]))
+        self.addconfiguration("qz", np.array([0, 0, 0, 0, 0, 0, 0, 0]))
+        self.addconfiguration("qr", np.array([0, -0.3, 0, -2.2, 0, 2.0, np.pi / 4, 0]))
 
 
-if __name__ == '__main__':   # pragma nocover
+if __name__ == "__main__":  # pragma nocover
 
     robot = vx300()
     print(robot)
